@@ -1,8 +1,9 @@
-from ezdnac.dnac import *
-from ezdnac.device import *
-from ezdnac.template import *
+from ezdnac.dnac.dnac import *
+from ezdnac.device.device import *
+from ezdnac.template.template import *
 import warnings
 
+
 warnings.filterwarnings('ignore', message='Unverified HTTPS request')
 authToken = None
 timeout = None
